@@ -13,6 +13,6 @@ class Configuration(ModelSingleton, ModelSQL, ModelView):
     production_sequence = fields.Property(fields.Many2One('ir.sequence',
             'Production Sequence', domain=[
                 ('company', 'in',
-                    [Eval('context', {}).get('company'), False]),
+                    [Eval('context', {}).get('company', -1), None]),
                 ('code', '=', 'production'),
                 ], required=True))
